This history lists major release themes. See the GitHub commits
for change details.

2.1.2 / 2014-12-16
------------------
* Adapt for PyPI.

2.1.1 / 2014-12-15
------------------
* Split out from qiutil.
